# Clara Pip Package

Enables easy inclusion of the Clara system. For full customizability, setup from
the [main GitHub](https://github.com/huberf/clara-bot).

## Setup (With Pip)
* Run `pip install clara`
* Setup config.json and an accompanying conversation directory (instructions
  coming soon).
* Now import the library via `from clara import brain`, and run the `brain.run()` function to start loop.
